# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: constraints.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import messages_pb2 as messages__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11\x63onstraints.proto\x1a\x0emessages.proto\"\xbf\x01\n\x14SummaryConstraintMsg\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x66irst_field\x18\x02 \x01(\t\x12\x16\n\x0csecond_field\x18\x03 \x01(\tH\x00\x12\x0f\n\x05value\x18\x04 \x01(\x01H\x00\x12/\n\x07\x62\x65tween\x18\x05 \x01(\x0b\x32\x1c.SummaryBetweenConstraintMsgH\x00\x12\x0f\n\x02op\x18\x06 \x01(\x0e\x32\x03.Op\x12\x0f\n\x07verbose\x18\x07 \x01(\x08\x42\x08\n\x06second\"\x8c\x01\n\x1bSummaryBetweenConstraintMsg\x12\x16\n\x0csecond_field\x18\x01 \x01(\tH\x00\x12\x15\n\x0blower_value\x18\x02 \x01(\x01H\x00\x12\x15\n\x0bthird_field\x18\x03 \x01(\tH\x01\x12\x15\n\x0bupper_value\x18\x04 \x01(\x01H\x01\x42\x07\n\x05lowerB\x07\n\x05upper\"~\n\x12ValueConstraintMsg\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x05value\x18\x02 \x01(\x01H\x00\x12\x17\n\rregex_pattern\x18\x05 \x01(\tH\x00\x12\x0f\n\x02op\x18\x03 \x01(\x0e\x32\x03.Op\x12\x0f\n\x07verbose\x18\x04 \x01(\x08\x42\x0e\n\x0csecond_field\"?\n\x13ValueConstraintMsgs\x12(\n\x0b\x63onstraints\x18\x01 \x03(\x0b\x32\x13.ValueConstraintMsg\"C\n\x15SummaryConstraintMsgs\x12*\n\x0b\x63onstraints\x18\x01 \x03(\x0b\x32\x15.SummaryConstraintMsg\"\xf4\x02\n\x14\x44\x61tasetConstraintMsg\x12&\n\nproperties\x18\x01 \x01(\x0b\x32\x12.DatasetProperties\x12\x46\n\x11value_constraints\x18\x02 \x03(\x0b\x32+.DatasetConstraintMsg.ValueConstraintsEntry\x12J\n\x13summary_constraints\x18\x03 \x03(\x0b\x32-.DatasetConstraintMsg.SummaryConstraintsEntry\x1aM\n\x15ValueConstraintsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12#\n\x05value\x18\x02 \x01(\x0b\x32\x14.ValueConstraintMsgs:\x02\x38\x01\x1aQ\n\x17SummaryConstraintsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12%\n\x05value\x18\x02 \x01(\x0b\x32\x16.SummaryConstraintMsgs:\x02\x38\x01*b\n\x02Op\x12\n\n\x06unused\x10\x00\x12\x06\n\x02LT\x10\x01\x12\x06\n\x02LE\x10\x02\x12\x06\n\x02\x45Q\x10\x03\x12\x06\n\x02NE\x10\x04\x12\x06\n\x02GE\x10\x05\x12\x06\n\x02GT\x10\x06\x12\t\n\x05MATCH\x10\x07\x12\x0b\n\x07NOMATCH\x10\x08\x12\x08\n\x04\x42TWN\x10\tB,\n\x1b\x63om.whylogs.core.constraintB\x0b\x43onstraintsP\x01\x62\x06proto3')

_OP = DESCRIPTOR.enum_types_by_name['Op']
Op = enum_type_wrapper.EnumTypeWrapper(_OP)
unused = 0
LT = 1
LE = 2
EQ = 3
NE = 4
GE = 5
GT = 6
MATCH = 7
NOMATCH = 8
BTWN = 9


_SUMMARYCONSTRAINTMSG = DESCRIPTOR.message_types_by_name['SummaryConstraintMsg']
_SUMMARYBETWEENCONSTRAINTMSG = DESCRIPTOR.message_types_by_name['SummaryBetweenConstraintMsg']
_VALUECONSTRAINTMSG = DESCRIPTOR.message_types_by_name['ValueConstraintMsg']
_VALUECONSTRAINTMSGS = DESCRIPTOR.message_types_by_name['ValueConstraintMsgs']
_SUMMARYCONSTRAINTMSGS = DESCRIPTOR.message_types_by_name['SummaryConstraintMsgs']
_DATASETCONSTRAINTMSG = DESCRIPTOR.message_types_by_name['DatasetConstraintMsg']
_DATASETCONSTRAINTMSG_VALUECONSTRAINTSENTRY = _DATASETCONSTRAINTMSG.nested_types_by_name['ValueConstraintsEntry']
_DATASETCONSTRAINTMSG_SUMMARYCONSTRAINTSENTRY = _DATASETCONSTRAINTMSG.nested_types_by_name['SummaryConstraintsEntry']
SummaryConstraintMsg = _reflection.GeneratedProtocolMessageType('SummaryConstraintMsg', (_message.Message,), {
  'DESCRIPTOR' : _SUMMARYCONSTRAINTMSG,
  '__module__' : 'constraints_pb2'
  # @@protoc_insertion_point(class_scope:SummaryConstraintMsg)
  })
_sym_db.RegisterMessage(SummaryConstraintMsg)

SummaryBetweenConstraintMsg = _reflection.GeneratedProtocolMessageType('SummaryBetweenConstraintMsg', (_message.Message,), {
  'DESCRIPTOR' : _SUMMARYBETWEENCONSTRAINTMSG,
  '__module__' : 'constraints_pb2'
  # @@protoc_insertion_point(class_scope:SummaryBetweenConstraintMsg)
  })
_sym_db.RegisterMessage(SummaryBetweenConstraintMsg)

ValueConstraintMsg = _reflection.GeneratedProtocolMessageType('ValueConstraintMsg', (_message.Message,), {
  'DESCRIPTOR' : _VALUECONSTRAINTMSG,
  '__module__' : 'constraints_pb2'
  # @@protoc_insertion_point(class_scope:ValueConstraintMsg)
  })
_sym_db.RegisterMessage(ValueConstraintMsg)

ValueConstraintMsgs = _reflection.GeneratedProtocolMessageType('ValueConstraintMsgs', (_message.Message,), {
  'DESCRIPTOR' : _VALUECONSTRAINTMSGS,
  '__module__' : 'constraints_pb2'
  # @@protoc_insertion_point(class_scope:ValueConstraintMsgs)
  })
_sym_db.RegisterMessage(ValueConstraintMsgs)

SummaryConstraintMsgs = _reflection.GeneratedProtocolMessageType('SummaryConstraintMsgs', (_message.Message,), {
  'DESCRIPTOR' : _SUMMARYCONSTRAINTMSGS,
  '__module__' : 'constraints_pb2'
  # @@protoc_insertion_point(class_scope:SummaryConstraintMsgs)
  })
_sym_db.RegisterMessage(SummaryConstraintMsgs)

DatasetConstraintMsg = _reflection.GeneratedProtocolMessageType('DatasetConstraintMsg', (_message.Message,), {

  'ValueConstraintsEntry' : _reflection.GeneratedProtocolMessageType('ValueConstraintsEntry', (_message.Message,), {
    'DESCRIPTOR' : _DATASETCONSTRAINTMSG_VALUECONSTRAINTSENTRY,
    '__module__' : 'constraints_pb2'
    # @@protoc_insertion_point(class_scope:DatasetConstraintMsg.ValueConstraintsEntry)
    })
  ,

  'SummaryConstraintsEntry' : _reflection.GeneratedProtocolMessageType('SummaryConstraintsEntry', (_message.Message,), {
    'DESCRIPTOR' : _DATASETCONSTRAINTMSG_SUMMARYCONSTRAINTSENTRY,
    '__module__' : 'constraints_pb2'
    # @@protoc_insertion_point(class_scope:DatasetConstraintMsg.SummaryConstraintsEntry)
    })
  ,
  'DESCRIPTOR' : _DATASETCONSTRAINTMSG,
  '__module__' : 'constraints_pb2'
  # @@protoc_insertion_point(class_scope:DatasetConstraintMsg)
  })
_sym_db.RegisterMessage(DatasetConstraintMsg)
_sym_db.RegisterMessage(DatasetConstraintMsg.ValueConstraintsEntry)
_sym_db.RegisterMessage(DatasetConstraintMsg.SummaryConstraintsEntry)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033com.whylogs.core.constraintB\013ConstraintsP\001'
  _DATASETCONSTRAINTMSG_VALUECONSTRAINTSENTRY._options = None
  _DATASETCONSTRAINTMSG_VALUECONSTRAINTSENTRY._serialized_options = b'8\001'
  _DATASETCONSTRAINTMSG_SUMMARYCONSTRAINTSENTRY._options = None
  _DATASETCONSTRAINTMSG_SUMMARYCONSTRAINTSENTRY._serialized_options = b'8\001'
  _OP._serialized_start=1011
  _OP._serialized_end=1109
  _SUMMARYCONSTRAINTMSG._serialized_start=38
  _SUMMARYCONSTRAINTMSG._serialized_end=229
  _SUMMARYBETWEENCONSTRAINTMSG._serialized_start=232
  _SUMMARYBETWEENCONSTRAINTMSG._serialized_end=372
  _VALUECONSTRAINTMSG._serialized_start=374
  _VALUECONSTRAINTMSG._serialized_end=500
  _VALUECONSTRAINTMSGS._serialized_start=502
  _VALUECONSTRAINTMSGS._serialized_end=565
  _SUMMARYCONSTRAINTMSGS._serialized_start=567
  _SUMMARYCONSTRAINTMSGS._serialized_end=634
  _DATASETCONSTRAINTMSG._serialized_start=637
  _DATASETCONSTRAINTMSG._serialized_end=1009
  _DATASETCONSTRAINTMSG_VALUECONSTRAINTSENTRY._serialized_start=849
  _DATASETCONSTRAINTMSG_VALUECONSTRAINTSENTRY._serialized_end=926
  _DATASETCONSTRAINTMSG_SUMMARYCONSTRAINTSENTRY._serialized_start=928
  _DATASETCONSTRAINTMSG_SUMMARYCONSTRAINTSENTRY._serialized_end=1009
# @@protoc_insertion_point(module_scope)
