# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: messages.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0emessages.proto\x1a\x1egoogle/protobuf/wrappers.proto\"\x7f\n\x08\x43ounters\x12\r\n\x05\x63ount\x18\x01 \x01(\x03\x12/\n\ntrue_count\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x33\n\nnull_count\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x02\x18\x01\"\x95\x01\n\x0cInferredType\x12 \n\x04type\x18\x01 \x01(\x0e\x32\x12.InferredType.Type\x12\r\n\x05ratio\x18\x02 \x01(\x01\"T\n\x04Type\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x08\n\x04NULL\x10\x01\x12\x0e\n\nFRACTIONAL\x10\x02\x12\x0c\n\x08INTEGRAL\x10\x03\x12\x0b\n\x07\x42OOLEAN\x10\x04\x12\n\n\x06STRING\x10\x05\"F\n\x0e\x44oublesMessage\x12\r\n\x05\x63ount\x18\x01 \x01(\x03\x12\x0b\n\x03min\x18\x02 \x01(\x01\x12\x0b\n\x03max\x18\x03 \x01(\x01\x12\x0b\n\x03sum\x18\x04 \x01(\x01\"D\n\x0cLongsMessage\x12\r\n\x05\x63ount\x18\x01 \x01(\x03\x12\x0b\n\x03min\x18\x02 \x01(\x03\x12\x0b\n\x03max\x18\x03 \x01(\x03\x12\x0b\n\x03sum\x18\x04 \x01(\x03\";\n\x0fVarianceMessage\x12\r\n\x05\x63ount\x18\x01 \x01(\x03\x12\x0b\n\x03sum\x18\x02 \x01(\x01\x12\x0c\n\x04mean\x18\x03 \x01(\x01\"@\n\x1c\x46requentNumbersSketchMessage\x12\x0e\n\x06sketch\x18\x01 \x01(\x0c\x12\x10\n\x08lg_max_k\x18\x02 \x01(\x05\">\n\x1a\x46requentItemsSketchMessage\x12\x0e\n\x06sketch\x18\x01 \x01(\x0c\x12\x10\n\x08lg_max_k\x18\x02 \x01(\x05\"\xf5\x01\n\x0eNumbersMessage\x12\"\n\x08variance\x18\x01 \x01(\x0b\x32\x10.VarianceMessage\x12\"\n\x07\x64oubles\x18\x02 \x01(\x0b\x32\x0f.DoublesMessageH\x00\x12\x1e\n\x05longs\x18\x03 \x01(\x0b\x32\r.LongsMessageH\x00\x12\x11\n\thistogram\x18\x04 \x01(\x0c\x12\r\n\x05theta\x18\x05 \x01(\x0c\x12\x15\n\rcompact_theta\x18\x06 \x01(\x0c\x12\x37\n\x10\x66requent_numbers\x18\x07 \x01(\x0b\x32\x1d.FrequentNumbersSketchMessageB\t\n\x07numbers\"\x9e\x01\n\x0e\x43harPosMessage\x12\x11\n\tchar_list\x18\x01 \x01(\t\x12\x35\n\x0c\x63har_pos_map\x18\x02 \x03(\x0b\x32\x1f.CharPosMessage.CharPosMapEntry\x1a\x42\n\x0f\x43harPosMapEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1e\n\x05value\x18\x02 \x01(\x0b\x32\x0f.NumbersMessage:\x02\x38\x01\"\xc7\x01\n\x0eStringsMessage\x12\r\n\x05\x63ount\x18\x01 \x01(\x03\x12\r\n\x05theta\x18\x02 \x01(\x0c\x12\r\n\x05items\x18\x03 \x01(\x0c\x12\x15\n\rcompact_theta\x18\x04 \x01(\x0c\x12\x1f\n\x06length\x18\x05 \x01(\x0b\x32\x0f.NumbersMessage\x12%\n\x0ctoken_length\x18\x06 \x01(\x0b\x32\x0f.NumbersMessage\x12)\n\x10\x63har_pos_tracker\x18\x07 \x01(\x0b\x32\x0f.CharPosMessage\"\x9c\x01\n\rSchemaMessage\x12\x32\n\ntypeCounts\x18\x01 \x03(\x0b\x32\x1e.SchemaMessage.TypeCountsEntry\x12$\n\rinferred_type\x18\x02 \x01(\x0b\x32\r.InferredType\x1a\x31\n\x0fTypeCountsEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x03:\x02\x38\x01\"\xa9\x02\n\rColumnMessage\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x1b\n\x08\x63ounters\x18\x02 \x01(\x0b\x32\t.Counters\x12\x1e\n\x06schema\x18\x03 \x01(\x0b\x32\x0e.SchemaMessage\x12 \n\x07numbers\x18\x04 \x01(\x0b\x32\x0f.NumbersMessage\x12 \n\x07strings\x18\x05 \x01(\x0b\x32\x0f.StringsMessage\x12$\n\rinferred_type\x18\x06 \x01(\x0b\x32\r.InferredType\x12\x33\n\x0e\x66requent_items\x18\x07 \x01(\x0b\x32\x1b.FrequentItemsSketchMessage\x12.\n\x13\x63\x61rdinality_tracker\x18\x08 \x01(\x0b\x32\x11.HllSketchMessage\"\xd4\x02\n\x11\x44\x61tasetProperties\x12\x1c\n\x14schema_major_version\x18\x01 \x01(\r\x12\x1c\n\x14schema_minor_version\x18\x02 \x01(\r\x12\x12\n\nsession_id\x18\x03 \x01(\t\x12\x19\n\x11session_timestamp\x18\x04 \x01(\x03\x12\x16\n\x0e\x64\x61ta_timestamp\x18\x05 \x01(\x03\x12*\n\x04tags\x18\x06 \x03(\x0b\x32\x1c.DatasetProperties.TagsEntry\x12\x32\n\x08metadata\x18\x07 \x03(\x0b\x32 .DatasetProperties.MetadataEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x8a\x01\n\x12ScoreMatrixMessage\x12\x0e\n\x06labels\x18\x01 \x03(\t\x12\x18\n\x10prediction_field\x18\x02 \x01(\t\x12\x14\n\x0ctarget_field\x18\x03 \x01(\t\x12\x13\n\x0bscore_field\x18\x04 \x01(\t\x12\x1f\n\x06scores\x18\n \x03(\x0b\x32\x0f.NumbersMessage\"\x94\x01\n\x18RegressionMetricsMessage\x12\x18\n\x10prediction_field\x18\x01 \x01(\t\x12\x14\n\x0ctarget_field\x18\x02 \x01(\t\x12\r\n\x05\x63ount\x18\x03 \x01(\x04\x12\x14\n\x0csum_abs_diff\x18\x04 \x01(\x01\x12\x10\n\x08sum_diff\x18\x05 \x01(\x01\x12\x11\n\tsum2_diff\x18\x06 \x01(\x01\"m\n\x11NLPMetricsMessage\x12\x1c\n\x03mer\x18\x01 \x01(\x0b\x32\x0f.NumbersMessage\x12\x1c\n\x03wer\x18\x02 \x01(\x0b\x32\x0f.NumbersMessage\x12\x1c\n\x03wil\x18\x03 \x01(\x0b\x32\x0f.NumbersMessage\"\x94\x01\n\x13ModelMetricsMessage\x12(\n\x0bscoreMatrix\x18\x01 \x01(\x0b\x32\x13.ScoreMatrixMessage\x12\x1d\n\tmodelType\x18\x02 \x01(\x0e\x32\n.ModelType\x12\x34\n\x11regressionMetrics\x18\x03 \x01(\x0b\x32\x19.RegressionMetricsMessage\"S\n\x13ModelProfileMessage\x12\x15\n\routput_fields\x18\x01 \x03(\t\x12%\n\x07metrics\x18\n \x01(\x0b\x32\x14.ModelMetricsMessage\"\xe0\x01\n\x15\x44\x61tasetProfileMessage\x12&\n\nproperties\x18\x01 \x01(\x0b\x32\x12.DatasetProperties\x12\x34\n\x07\x63olumns\x18\x02 \x03(\x0b\x32#.DatasetProfileMessage.ColumnsEntry\x12)\n\x0bmodeProfile\x18\n \x01(\x0b\x32\x14.ModelProfileMessage\x1a>\n\x0c\x43olumnsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1d\n\x05value\x18\x02 \x01(\x0b\x32\x0e.ColumnMessage:\x02\x38\x01\"F\n\x13\x43olumnsChunkSegment\x12\x0e\n\x06marker\x18\x01 \x01(\t\x12\x1f\n\x07\x63olumns\x18\x02 \x03(\x0b\x32\x0e.ColumnMessage\"P\n\x16\x44\x61tasetMetadataSegment\x12\x0e\n\x06marker\x18\x01 \x01(\t\x12&\n\nproperties\x18\x02 \x01(\x0b\x32\x12.DatasetProperties\"~\n\x0eMessageSegment\x12\x0e\n\x06marker\x18\x01 \x01(\t\x12+\n\x08metadata\x18\x02 \x01(\x0b\x32\x17.DatasetMetadataSegmentH\x00\x12\'\n\x07\x63olumns\x18\x03 \x01(\x0b\x32\x14.ColumnsChunkSegmentH\x00\x42\x06\n\x04item\"0\n\x10HllSketchMessage\x12\x0e\n\x06sketch\x18\x01 \x01(\x0c\x12\x0c\n\x04lg_k\x18\x02 \x01(\x05*U\n\tModelType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x12\n\x0e\x43LASSIFICATION\x10\x01\x12\x0e\n\nREGRESSION\x10\x02\x12\x0e\n\nEMBEDDINGS\x10\x03\x12\x07\n\x03NLP\x10\x04\x42&\n\x18\x63om.whylogs.core.messageB\x08MessagesP\x01\x62\x06proto3')

_MODELTYPE = DESCRIPTOR.enum_types_by_name['ModelType']
ModelType = enum_type_wrapper.EnumTypeWrapper(_MODELTYPE)
UNKNOWN = 0
CLASSIFICATION = 1
REGRESSION = 2
EMBEDDINGS = 3
NLP = 4


_COUNTERS = DESCRIPTOR.message_types_by_name['Counters']
_INFERREDTYPE = DESCRIPTOR.message_types_by_name['InferredType']
_DOUBLESMESSAGE = DESCRIPTOR.message_types_by_name['DoublesMessage']
_LONGSMESSAGE = DESCRIPTOR.message_types_by_name['LongsMessage']
_VARIANCEMESSAGE = DESCRIPTOR.message_types_by_name['VarianceMessage']
_FREQUENTNUMBERSSKETCHMESSAGE = DESCRIPTOR.message_types_by_name['FrequentNumbersSketchMessage']
_FREQUENTITEMSSKETCHMESSAGE = DESCRIPTOR.message_types_by_name['FrequentItemsSketchMessage']
_NUMBERSMESSAGE = DESCRIPTOR.message_types_by_name['NumbersMessage']
_CHARPOSMESSAGE = DESCRIPTOR.message_types_by_name['CharPosMessage']
_CHARPOSMESSAGE_CHARPOSMAPENTRY = _CHARPOSMESSAGE.nested_types_by_name['CharPosMapEntry']
_STRINGSMESSAGE = DESCRIPTOR.message_types_by_name['StringsMessage']
_SCHEMAMESSAGE = DESCRIPTOR.message_types_by_name['SchemaMessage']
_SCHEMAMESSAGE_TYPECOUNTSENTRY = _SCHEMAMESSAGE.nested_types_by_name['TypeCountsEntry']
_COLUMNMESSAGE = DESCRIPTOR.message_types_by_name['ColumnMessage']
_DATASETPROPERTIES = DESCRIPTOR.message_types_by_name['DatasetProperties']
_DATASETPROPERTIES_TAGSENTRY = _DATASETPROPERTIES.nested_types_by_name['TagsEntry']
_DATASETPROPERTIES_METADATAENTRY = _DATASETPROPERTIES.nested_types_by_name['MetadataEntry']
_SCOREMATRIXMESSAGE = DESCRIPTOR.message_types_by_name['ScoreMatrixMessage']
_REGRESSIONMETRICSMESSAGE = DESCRIPTOR.message_types_by_name['RegressionMetricsMessage']
_NLPMETRICSMESSAGE = DESCRIPTOR.message_types_by_name['NLPMetricsMessage']
_MODELMETRICSMESSAGE = DESCRIPTOR.message_types_by_name['ModelMetricsMessage']
_MODELPROFILEMESSAGE = DESCRIPTOR.message_types_by_name['ModelProfileMessage']
_DATASETPROFILEMESSAGE = DESCRIPTOR.message_types_by_name['DatasetProfileMessage']
_DATASETPROFILEMESSAGE_COLUMNSENTRY = _DATASETPROFILEMESSAGE.nested_types_by_name['ColumnsEntry']
_COLUMNSCHUNKSEGMENT = DESCRIPTOR.message_types_by_name['ColumnsChunkSegment']
_DATASETMETADATASEGMENT = DESCRIPTOR.message_types_by_name['DatasetMetadataSegment']
_MESSAGESEGMENT = DESCRIPTOR.message_types_by_name['MessageSegment']
_HLLSKETCHMESSAGE = DESCRIPTOR.message_types_by_name['HllSketchMessage']
_INFERREDTYPE_TYPE = _INFERREDTYPE.enum_types_by_name['Type']
Counters = _reflection.GeneratedProtocolMessageType('Counters', (_message.Message,), {
  'DESCRIPTOR' : _COUNTERS,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:Counters)
  })
_sym_db.RegisterMessage(Counters)

InferredType = _reflection.GeneratedProtocolMessageType('InferredType', (_message.Message,), {
  'DESCRIPTOR' : _INFERREDTYPE,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:InferredType)
  })
_sym_db.RegisterMessage(InferredType)

DoublesMessage = _reflection.GeneratedProtocolMessageType('DoublesMessage', (_message.Message,), {
  'DESCRIPTOR' : _DOUBLESMESSAGE,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:DoublesMessage)
  })
_sym_db.RegisterMessage(DoublesMessage)

LongsMessage = _reflection.GeneratedProtocolMessageType('LongsMessage', (_message.Message,), {
  'DESCRIPTOR' : _LONGSMESSAGE,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:LongsMessage)
  })
_sym_db.RegisterMessage(LongsMessage)

VarianceMessage = _reflection.GeneratedProtocolMessageType('VarianceMessage', (_message.Message,), {
  'DESCRIPTOR' : _VARIANCEMESSAGE,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:VarianceMessage)
  })
_sym_db.RegisterMessage(VarianceMessage)

FrequentNumbersSketchMessage = _reflection.GeneratedProtocolMessageType('FrequentNumbersSketchMessage', (_message.Message,), {
  'DESCRIPTOR' : _FREQUENTNUMBERSSKETCHMESSAGE,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:FrequentNumbersSketchMessage)
  })
_sym_db.RegisterMessage(FrequentNumbersSketchMessage)

FrequentItemsSketchMessage = _reflection.GeneratedProtocolMessageType('FrequentItemsSketchMessage', (_message.Message,), {
  'DESCRIPTOR' : _FREQUENTITEMSSKETCHMESSAGE,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:FrequentItemsSketchMessage)
  })
_sym_db.RegisterMessage(FrequentItemsSketchMessage)

NumbersMessage = _reflection.GeneratedProtocolMessageType('NumbersMessage', (_message.Message,), {
  'DESCRIPTOR' : _NUMBERSMESSAGE,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:NumbersMessage)
  })
_sym_db.RegisterMessage(NumbersMessage)

CharPosMessage = _reflection.GeneratedProtocolMessageType('CharPosMessage', (_message.Message,), {

  'CharPosMapEntry' : _reflection.GeneratedProtocolMessageType('CharPosMapEntry', (_message.Message,), {
    'DESCRIPTOR' : _CHARPOSMESSAGE_CHARPOSMAPENTRY,
    '__module__' : 'messages_pb2'
    # @@protoc_insertion_point(class_scope:CharPosMessage.CharPosMapEntry)
    })
  ,
  'DESCRIPTOR' : _CHARPOSMESSAGE,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:CharPosMessage)
  })
_sym_db.RegisterMessage(CharPosMessage)
_sym_db.RegisterMessage(CharPosMessage.CharPosMapEntry)

StringsMessage = _reflection.GeneratedProtocolMessageType('StringsMessage', (_message.Message,), {
  'DESCRIPTOR' : _STRINGSMESSAGE,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:StringsMessage)
  })
_sym_db.RegisterMessage(StringsMessage)

SchemaMessage = _reflection.GeneratedProtocolMessageType('SchemaMessage', (_message.Message,), {

  'TypeCountsEntry' : _reflection.GeneratedProtocolMessageType('TypeCountsEntry', (_message.Message,), {
    'DESCRIPTOR' : _SCHEMAMESSAGE_TYPECOUNTSENTRY,
    '__module__' : 'messages_pb2'
    # @@protoc_insertion_point(class_scope:SchemaMessage.TypeCountsEntry)
    })
  ,
  'DESCRIPTOR' : _SCHEMAMESSAGE,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:SchemaMessage)
  })
_sym_db.RegisterMessage(SchemaMessage)
_sym_db.RegisterMessage(SchemaMessage.TypeCountsEntry)

ColumnMessage = _reflection.GeneratedProtocolMessageType('ColumnMessage', (_message.Message,), {
  'DESCRIPTOR' : _COLUMNMESSAGE,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:ColumnMessage)
  })
_sym_db.RegisterMessage(ColumnMessage)

DatasetProperties = _reflection.GeneratedProtocolMessageType('DatasetProperties', (_message.Message,), {

  'TagsEntry' : _reflection.GeneratedProtocolMessageType('TagsEntry', (_message.Message,), {
    'DESCRIPTOR' : _DATASETPROPERTIES_TAGSENTRY,
    '__module__' : 'messages_pb2'
    # @@protoc_insertion_point(class_scope:DatasetProperties.TagsEntry)
    })
  ,

  'MetadataEntry' : _reflection.GeneratedProtocolMessageType('MetadataEntry', (_message.Message,), {
    'DESCRIPTOR' : _DATASETPROPERTIES_METADATAENTRY,
    '__module__' : 'messages_pb2'
    # @@protoc_insertion_point(class_scope:DatasetProperties.MetadataEntry)
    })
  ,
  'DESCRIPTOR' : _DATASETPROPERTIES,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:DatasetProperties)
  })
_sym_db.RegisterMessage(DatasetProperties)
_sym_db.RegisterMessage(DatasetProperties.TagsEntry)
_sym_db.RegisterMessage(DatasetProperties.MetadataEntry)

ScoreMatrixMessage = _reflection.GeneratedProtocolMessageType('ScoreMatrixMessage', (_message.Message,), {
  'DESCRIPTOR' : _SCOREMATRIXMESSAGE,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:ScoreMatrixMessage)
  })
_sym_db.RegisterMessage(ScoreMatrixMessage)

RegressionMetricsMessage = _reflection.GeneratedProtocolMessageType('RegressionMetricsMessage', (_message.Message,), {
  'DESCRIPTOR' : _REGRESSIONMETRICSMESSAGE,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:RegressionMetricsMessage)
  })
_sym_db.RegisterMessage(RegressionMetricsMessage)

NLPMetricsMessage = _reflection.GeneratedProtocolMessageType('NLPMetricsMessage', (_message.Message,), {
  'DESCRIPTOR' : _NLPMETRICSMESSAGE,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:NLPMetricsMessage)
  })
_sym_db.RegisterMessage(NLPMetricsMessage)

ModelMetricsMessage = _reflection.GeneratedProtocolMessageType('ModelMetricsMessage', (_message.Message,), {
  'DESCRIPTOR' : _MODELMETRICSMESSAGE,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:ModelMetricsMessage)
  })
_sym_db.RegisterMessage(ModelMetricsMessage)

ModelProfileMessage = _reflection.GeneratedProtocolMessageType('ModelProfileMessage', (_message.Message,), {
  'DESCRIPTOR' : _MODELPROFILEMESSAGE,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:ModelProfileMessage)
  })
_sym_db.RegisterMessage(ModelProfileMessage)

DatasetProfileMessage = _reflection.GeneratedProtocolMessageType('DatasetProfileMessage', (_message.Message,), {

  'ColumnsEntry' : _reflection.GeneratedProtocolMessageType('ColumnsEntry', (_message.Message,), {
    'DESCRIPTOR' : _DATASETPROFILEMESSAGE_COLUMNSENTRY,
    '__module__' : 'messages_pb2'
    # @@protoc_insertion_point(class_scope:DatasetProfileMessage.ColumnsEntry)
    })
  ,
  'DESCRIPTOR' : _DATASETPROFILEMESSAGE,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:DatasetProfileMessage)
  })
_sym_db.RegisterMessage(DatasetProfileMessage)
_sym_db.RegisterMessage(DatasetProfileMessage.ColumnsEntry)

ColumnsChunkSegment = _reflection.GeneratedProtocolMessageType('ColumnsChunkSegment', (_message.Message,), {
  'DESCRIPTOR' : _COLUMNSCHUNKSEGMENT,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:ColumnsChunkSegment)
  })
_sym_db.RegisterMessage(ColumnsChunkSegment)

DatasetMetadataSegment = _reflection.GeneratedProtocolMessageType('DatasetMetadataSegment', (_message.Message,), {
  'DESCRIPTOR' : _DATASETMETADATASEGMENT,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:DatasetMetadataSegment)
  })
_sym_db.RegisterMessage(DatasetMetadataSegment)

MessageSegment = _reflection.GeneratedProtocolMessageType('MessageSegment', (_message.Message,), {
  'DESCRIPTOR' : _MESSAGESEGMENT,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:MessageSegment)
  })
_sym_db.RegisterMessage(MessageSegment)

HllSketchMessage = _reflection.GeneratedProtocolMessageType('HllSketchMessage', (_message.Message,), {
  'DESCRIPTOR' : _HLLSKETCHMESSAGE,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:HllSketchMessage)
  })
_sym_db.RegisterMessage(HllSketchMessage)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\030com.whylogs.core.messageB\010MessagesP\001'
  _COUNTERS.fields_by_name['null_count']._options = None
  _COUNTERS.fields_by_name['null_count']._serialized_options = b'\030\001'
  _CHARPOSMESSAGE_CHARPOSMAPENTRY._options = None
  _CHARPOSMESSAGE_CHARPOSMAPENTRY._serialized_options = b'8\001'
  _SCHEMAMESSAGE_TYPECOUNTSENTRY._options = None
  _SCHEMAMESSAGE_TYPECOUNTSENTRY._serialized_options = b'8\001'
  _DATASETPROPERTIES_TAGSENTRY._options = None
  _DATASETPROPERTIES_TAGSENTRY._serialized_options = b'8\001'
  _DATASETPROPERTIES_METADATAENTRY._options = None
  _DATASETPROPERTIES_METADATAENTRY._serialized_options = b'8\001'
  _DATASETPROFILEMESSAGE_COLUMNSENTRY._options = None
  _DATASETPROFILEMESSAGE_COLUMNSENTRY._serialized_options = b'8\001'
  _MODELTYPE._serialized_start=3275
  _MODELTYPE._serialized_end=3360
  _COUNTERS._serialized_start=50
  _COUNTERS._serialized_end=177
  _INFERREDTYPE._serialized_start=180
  _INFERREDTYPE._serialized_end=329
  _INFERREDTYPE_TYPE._serialized_start=245
  _INFERREDTYPE_TYPE._serialized_end=329
  _DOUBLESMESSAGE._serialized_start=331
  _DOUBLESMESSAGE._serialized_end=401
  _LONGSMESSAGE._serialized_start=403
  _LONGSMESSAGE._serialized_end=471
  _VARIANCEMESSAGE._serialized_start=473
  _VARIANCEMESSAGE._serialized_end=532
  _FREQUENTNUMBERSSKETCHMESSAGE._serialized_start=534
  _FREQUENTNUMBERSSKETCHMESSAGE._serialized_end=598
  _FREQUENTITEMSSKETCHMESSAGE._serialized_start=600
  _FREQUENTITEMSSKETCHMESSAGE._serialized_end=662
  _NUMBERSMESSAGE._serialized_start=665
  _NUMBERSMESSAGE._serialized_end=910
  _CHARPOSMESSAGE._serialized_start=913
  _CHARPOSMESSAGE._serialized_end=1071
  _CHARPOSMESSAGE_CHARPOSMAPENTRY._serialized_start=1005
  _CHARPOSMESSAGE_CHARPOSMAPENTRY._serialized_end=1071
  _STRINGSMESSAGE._serialized_start=1074
  _STRINGSMESSAGE._serialized_end=1273
  _SCHEMAMESSAGE._serialized_start=1276
  _SCHEMAMESSAGE._serialized_end=1432
  _SCHEMAMESSAGE_TYPECOUNTSENTRY._serialized_start=1383
  _SCHEMAMESSAGE_TYPECOUNTSENTRY._serialized_end=1432
  _COLUMNMESSAGE._serialized_start=1435
  _COLUMNMESSAGE._serialized_end=1732
  _DATASETPROPERTIES._serialized_start=1735
  _DATASETPROPERTIES._serialized_end=2075
  _DATASETPROPERTIES_TAGSENTRY._serialized_start=1983
  _DATASETPROPERTIES_TAGSENTRY._serialized_end=2026
  _DATASETPROPERTIES_METADATAENTRY._serialized_start=2028
  _DATASETPROPERTIES_METADATAENTRY._serialized_end=2075
  _SCOREMATRIXMESSAGE._serialized_start=2078
  _SCOREMATRIXMESSAGE._serialized_end=2216
  _REGRESSIONMETRICSMESSAGE._serialized_start=2219
  _REGRESSIONMETRICSMESSAGE._serialized_end=2367
  _NLPMETRICSMESSAGE._serialized_start=2369
  _NLPMETRICSMESSAGE._serialized_end=2478
  _MODELMETRICSMESSAGE._serialized_start=2481
  _MODELMETRICSMESSAGE._serialized_end=2629
  _MODELPROFILEMESSAGE._serialized_start=2631
  _MODELPROFILEMESSAGE._serialized_end=2714
  _DATASETPROFILEMESSAGE._serialized_start=2717
  _DATASETPROFILEMESSAGE._serialized_end=2941
  _DATASETPROFILEMESSAGE_COLUMNSENTRY._serialized_start=2879
  _DATASETPROFILEMESSAGE_COLUMNSENTRY._serialized_end=2941
  _COLUMNSCHUNKSEGMENT._serialized_start=2943
  _COLUMNSCHUNKSEGMENT._serialized_end=3013
  _DATASETMETADATASEGMENT._serialized_start=3015
  _DATASETMETADATASEGMENT._serialized_end=3095
  _MESSAGESEGMENT._serialized_start=3097
  _MESSAGESEGMENT._serialized_end=3223
  _HLLSKETCHMESSAGE._serialized_start=3225
  _HLLSKETCHMESSAGE._serialized_end=3273
# @@protoc_insertion_point(module_scope)
